#!/usr/bin/env python

import copy
from dmObject import DmObject
from dm.common.utility.dictUtility import DictUtility

class DaqInfo(DmObject):

    DEFAULT_KEY_LIST = [ 'id', 'experimentName', 'dataDirectory', 'status', 'nProcessedFiles', 'nFiles', 'startTimestamp', 'endTimestamp' ]

    def __init__(self, dict={}):
        DmObject.__init__(self, dict)
        self.originalKeys = dict.keys()
        self['fileDict'] = self.get('fileDict', {})

    def updateStatus(self):
        daqStatus = self.get('status', 'running')
        if daqStatus == 'done':          
            return 
        fileDict = self.get('fileDict')
        nFiles = len(fileDict)
        nProcessedFiles = 0
        for (filePath,uploadFileInfo) in fileDict.items():
            if uploadFileInfo.get('processed'):
                 nProcessedFiles += 1                
        self['nProcessedFiles'] = '%s' % (nProcessedFiles)
        self['nFiles'] = '%s' % (nFiles)

        # need to handle 'failed' uploads
        if self.get('endTime'):
            daqStatus = 'done'
        self['status'] = daqStatus

    def toDictWithOriginalKeys(self):
        dict = copy.deepcopy(self.data)
        for key in dict.keys():
            if key not in self.originalKeys:
                del dict[key]
        return dict

    def scrub(self):
        # Remove redundant information
        daqInfo2 = DictUtility.deepCopy(self.data, excludeKeys='fileDict')
        fileDict = self.get('fileDict', {})
        fileDict2 = {}
        for (filePath,fileInfo) in fileDict.items():
            fileInfo2 = {}
            for key in ['processed', 'lastUpdateTime']:
                if fileInfo.has_key(key):
                    fileInfo2[key] = fileInfo[key]
            fileDict2[filePath] = fileInfo2
        daqInfo2['fileDict'] = fileDict2
        return DaqInfo(daqInfo2)
